@@ -3,16 +3,9 @@ library("vcr")
 
 invisible(vcr::vcr_configure(
   filter_sensitive_data = list(
-    "<<CLIENT_SECRET>>" = Sys.getenv("NETTSKJEMA_CLIENT_SECRET"),
-    "<<BASIC_AUTH>>" = openssl::base64_encode(
-      paste0(
-        Sys.getenv("NETTSKJEMA_CLIENT_ID"),
-        ":",
-        Sys.getenv("NETTSKJEMA_CLIENT_SECRET")
-      )
-    )
+    "<<CLIENT_SECRET>>" = Sys.getenv("NETTSKJEMA_CLIENT_SECRET")
   ),
-  dir = vcr::vcr_test_path("fixtures")
+  dir = vcr::vcr_test_path("_vcr")
 ))
 
 #' Helper function to mock Nettskjema authentication for VCR tests
@@ -28,8 +21,11 @@ with_mocked_nettskjema_auth <- function(expr) {
   force(expr)
 }
 
-vcr::check_cassette_names()
-
 form_id <- 123823
 submission_id <- 27685292
 attachment_id <- 538819
+
+# nolint start
+mock_client_id = "a1b2c3d4-e5f6-7890-abcd-ef1234567890"
+mock_client_secret = "aB3xK9mP2vQ8fR7nL98Mcs81sT4uY6wE5zC0hJ9iO3kM8pN2qA7bD1gF4jH6lS9vX3nR5mT8"
+# nolint end
